package com.io.yutian.elementoriginlib.item.stat.type;

import com.io.yutian.elementoriginlib.item.OriginItemStackBuilder;
import com.io.yutian.elementoriginlib.item.stat.ItemStat;
import com.io.yutian.elementoriginlib.item.stat.data.StringListData;
import com.io.yutian.elementoriginlib.nbt.NBTItem;
import com.io.yutian.elementoriginlib.nbt.TagList;
import com.io.yutian.elementoriginlib.nbt.TagString;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

public abstract class StringListStat extends ItemStat<StringListData> {

    public StringListStat(@NotNull String id, @NotNull String path) {
        super(id, path);
    }

    @Override
    public void whenApplied(@NotNull OriginItemStackBuilder itemStackBuilder, @NotNull StringListData statData) {
        NBTItem nbtItem = itemStackBuilder.getNBTItem();
        TagList<TagString> tagList = new TagList<>();
        statData.getList().forEach(s -> tagList.add(new TagString(s)));
        nbtItem.editTag(nbtCompound -> nbtCompound.put(getNBTPath(), tagList));
    }

    @Nullable
    @Override
    public StringListData getLoadedNBT(@NotNull NBTItem nbtItem) {
        if (!nbtItem.has(getNBTPath(), TagList.TYPE_ID)) {
            return new StringListData(new ArrayList<>());
        }
        TagList<TagString> tagList = (TagList<TagString>) nbtItem.get(getNBTPath());
        List<String> list = new ArrayList<>();
        for (int i = 0; i < tagList.size(); i++) {
            list.add(tagList.get(i).getString());
        }
        return new StringListData(list);
    }

}
